@@ -1,7 +1,6 @@
 #ifndef INCLUDE_RUBY_CONFIG_H
 #define INCLUDE_RUBY_CONFIG_H 1
 /* confdefs.h */
-#define CANONICALIZATION_FOR_MATHN 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_STAT_H 1
@@ -17,10 +16,9 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
-#define HAVE_INFINITY 1
-#define HAVE_NAN 1
 #define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
 #define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
+#define HAVE_STMT_AND_DECL_IN_EXPR 1
 #define HAVE_DIRENT_H 1
 #define HAVE__BOOL 1
 #define HAVE_STDBOOL_H 1
@@ -67,46 +65,55 @@
 #define PACKED_STRUCT(x) x __attribute__((packed))
 #define USE_UNALIGNED_MEMBER_ACCESS 1
 #define PRI_LL_PREFIX "ll"
+#define HAVE_PID_T 1
 #define rb_pid_t pid_t
 #define SIGNEDNESS_OF_PID_T -1
 #define PIDT2NUM(v) INT2NUM(v)
 #define NUM2PIDT(v) NUM2INT(v)
 #define PRI_PIDT_PREFIX PRI_INT_PREFIX
+#define HAVE_UID_T 1
 #define rb_uid_t uid_t
 #define SIGNEDNESS_OF_UID_T +1
 #define UIDT2NUM(v) UINT2NUM(v)
 #define NUM2UIDT(v) NUM2UINT(v)
 #define PRI_UIDT_PREFIX PRI_INT_PREFIX
+#define HAVE_GID_T 1
 #define rb_gid_t gid_t
 #define SIGNEDNESS_OF_GID_T +1
 #define GIDT2NUM(v) UINT2NUM(v)
 #define NUM2GIDT(v) NUM2UINT(v)
 #define PRI_GIDT_PREFIX PRI_INT_PREFIX
+#define HAVE_TIME_T 1
 #define rb_time_t time_t
 #define SIGNEDNESS_OF_TIME_T -1
 #define TIMET2NUM(v) LL2NUM(v)
 #define NUM2TIMET(v) NUM2LL(v)
 #define PRI_TIMET_PREFIX PRI_LL_PREFIX
+#define HAVE_DEV_T 1
 #define rb_dev_t dev_t
 #define SIGNEDNESS_OF_DEV_T -1
 #define DEVT2NUM(v) INT2NUM(v)
 #define NUM2DEVT(v) NUM2INT(v)
 #define PRI_DEVT_PREFIX PRI_INT_PREFIX
+#define HAVE_MODE_T 1
 #define rb_mode_t mode_t
 #define SIGNEDNESS_OF_MODE_T +1
 #define MODET2NUM(v) UINT2NUM(v)
 #define NUM2MODET(v) NUM2UINT(v)
 #define PRI_MODET_PREFIX PRI_INT_PREFIX
+#define HAVE_RLIM_T 1
 #define rb_rlim_t rlim_t
 #define SIGNEDNESS_OF_RLIM_T +1
 #define RLIM2NUM(v) ULL2NUM(v)
 #define NUM2RLIM(v) NUM2ULL(v)
 #define PRI_RLIM_PREFIX PRI_LL_PREFIX
+#define HAVE_OFF_T 1
 #define rb_off_t off_t
 #define SIGNEDNESS_OF_OFF_T -1
 #define OFFT2NUM(v) LL2NUM(v)
 #define NUM2OFFT(v) NUM2LL(v)
 #define PRI_OFFT_PREFIX PRI_LL_PREFIX
+#define HAVE_CLOCKID_T 1
 #define rb_clockid_t clockid_t
 #define SIGNEDNESS_OF_CLOCKID_T -1
 #define CLOCKID2NUM(v) INT2NUM(v)
@@ -117,6 +124,8 @@
 #define STRINGIZE(expr) STRINGIZE0(expr)
 #define HAVE_STDARG_PROTOTYPES 1
 #define HAVE_VA_ARGS_MACRO 1
+#define RUBY_ALIGNAS(x) __attribute__((__aligned__(x)))
+#define RUBY_ALIGNOF __alignof
 #define CONSTFUNC(x) __attribute__ ((__const__)) x
 #define PUREFUNC(x) __attribute__ ((__pure__)) x
 #define NORETURN(x) __attribute__ ((__noreturn__)) x
@@ -162,7 +171,6 @@
 #define SIZEOF_STRUCT_TIMEVAL_TV_SEC SIZEOF_TIME_T
 #define HAVE_STRUCT_TIMESPEC 1
 #define HAVE_STRUCT_TIMEZONE 1
-#define HAVE_CLOCKID_T 1
 #define HAVE_RB_FD_INIT 1
 #define HAVE_INT8_T 1
 #define SIZEOF_INT8_T 1
@@ -186,7 +194,7 @@
 #define SIZEOF_UINTPTR_T 8
 #define HAVE_SSIZE_T 1
 #define SIZEOF_SSIZE_T 8
-#define HEAP_PAGE_ALIGN_LOG 12
+#define PRI_64_PREFIX "ll"
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_ALLOCA 1
@@ -204,6 +212,7 @@
 #define HAVE_ISNAN 1
 #define HAVE_LGAMMA_R 1
 #define HAVE_MEMMOVE 1
+#define HAVE_NAN 1
 #define HAVE_NEXTAFTER 1
 #define HAVE_SETPROCTITLE 1
 #define HAVE_STRCHR 1
@@ -256,6 +265,7 @@
 #define HAVE_GETSID 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_GMTIME_R 1
+#define HAVE_GRANTPT 1
 #define HAVE_INITGROUPS 1
 #define HAVE_IOCTL 1
 #define HAVE_ISSETUGID 1
@@ -325,6 +335,7 @@
 #define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
+#define HAVE_BUILTIN___BUILTIN_TRAP 1
 #define ATAN2_INF_C99 1
 #define HAVE_CLOCK_GETRES 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
@@ -344,11 +355,9 @@
 #define HAVE_SCHED_YIELD 1
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
-#define HAVE_PTHREAD_ATTR_INIT 1
+#define HAVE_PTHREAD_ATTR_GETGUARDSIZE 1
 #define HAVE_PTHREAD_STACKSEG_NP 1
-#define HAVE_PTHREAD_COND_INIT 1
 #define HAVE_PTHREAD_CONDATTR_SETCLOCK 1
-#define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
 #define HAVE_PTHREAD_SET_NAME_NP 1
 #define SET_CURRENT_THREAD_NAME(name) pthread_set_name_np(pthread_self(), name)
@@ -366,6 +375,7 @@
 #define RUBY_SETJMP(env) _setjmp((env))
 #define RUBY_LONGJMP(env,val) _longjmp((env),val)
 #define RUBY_JMP_BUF jmp_buf
+#define USE_MJIT 1
 #define HAVE_PTHREAD_H 1
 #define RUBY_PLATFORM "mips64el-openbsd"
 #endif /* INCLUDE_RUBY_CONFIG_H */
